What is DssPyLib?

1) Python package for calculating 2-D integral and finite element numerical solutions for Poisson equation with simple non-overlapping shapes.
2) Provides support to apply integral Dirichelet boundary conditions for improved accuracy in open boundary problems.
3) Provides addition support to apply Distributed Source Scheme to reduce error due to presence of field sources.
4) Supports calculation of vector fields at any point inside the problem region and forces on the sources.

Dependencies:

Python 3.8+, Numpy 1.23.1, Joblib 1.1.0, Matplotlib 3.5.2, and Scipy 1.8.1

Version:

DssPyLib 0.2.0
